@@ -1,7 +1,7 @@
 """This is the “nester.py" module, and it provides one function called 
 print_lol() which prints lists that may or may not include nested lists."""
 
-def print_lol(the_list, indent = False, level = 0):
+def print_lol(the_list, indent = False, level = 0, file = sys.stdout):
     """This function takes a positional argument called “the_list", which is any 
     Python list (of, possibly, nested lists). Each data item in the provided list 
     is (recursively) printed to the screen on its own line.
@@ -9,9 +9,9 @@ def print_lol(the_list, indent = False, level = 0):
 
     for each_item in the_list:
         if isinstance(each_item, list):
-            print_lol(each_item, indent, level + 1)
+            print_lol(each_item, indent, level + 1, file)
         else:
             if indent:
                 for tab_stop in range(level):
-                    print("\t",end='')
-            print(each_item)
\ No newline at end of file
+                    print("\t", end='', file=file)
+            print(each_item, file=file)
\ No newline at end of file
